@@ -1,7 +1,6 @@
 import datetime
 import sys
 from os.path import exists
-from os.path import isdir
 from unittest import mock
 from unittest.mock import patch
 
@@ -245,13 +244,12 @@ def test_dtstamp(tmpdir, runner, create):
     assert todo.dtstamp == datetime.datetime.now(tz=tzlocal())
 
 
-def test_default_list(tmpdir, runner, create):
+def test_default_list(tmpdir, runner, create, config):
     """Test the default_list config parameter"""
     result = runner.invoke(cli, ["new", "test default list"])
     assert result.exception
 
-    path = tmpdir.join("config")
-    path.write("default_list = default\n", "a")
+    config.write('default_list = "default"\n', "a")
 
     result = runner.invoke(cli, ["new", "test default list"])
     assert not result.exception
@@ -266,11 +264,10 @@ def test_default_list(tmpdir, runner, create):
     [(None, 24), (1, 1), (0, None)],
     ids=["not specified", "greater than 0", "0"],
 )
-def test_default_due(tmpdir, runner, create, default_due, expected_due_hours):
+def test_default_due(tmpdir, runner, create, default_due, expected_due_hours, config):
     """Test setting the due date using the default_due config parameter"""
     if default_due is not None:
-        path = tmpdir.join("config")
-        path.write("default_due = {}\n".format(default_due), "a")
+        config.write(f"default_due = {default_due}\n", "a")
 
     runner.invoke(cli, ["new", "-l", "default", "aaa"])
     db = Database([tmpdir.join("default")], tmpdir.join("/default_list"))
@@ -286,9 +283,8 @@ def test_default_due(tmpdir, runner, create, default_due, expected_due_hours):
 
 @pyicu_sensitive
 @freeze_time(datetime.datetime.now())
-def test_default_due2(tmpdir, runner, create, todos):
-    cfg = tmpdir.join("config")
-    cfg.write("default_due = 24\n", "a")
+def test_default_due2(tmpdir, runner, create, todos, config):
+    config.write("default_due = 24\n", "a")
 
     r = runner.invoke(cli, ["new", "-ldefault", "-dtomorrow", "aaa"])
     assert not r.exception
@@ -311,7 +307,7 @@ def test_sorting_fields(tmpdir, runner, default_database):
         todo.list = next(default_database.lists())
         todo.due = datetime.datetime.now() + days
         todo.created_at = datetime.datetime.now() - days
-        todo.summary = "harhar{}".format(i)
+        todo.summary = f"harhar{i}"
         tasks.append(todo)
 
         default_database.save(todo)
@@ -404,11 +400,11 @@ def test_color_due_dates(tmpdir, runner, create, hours):
     assert not result.exception
     due_str = due.strftime("%Y-%m-%d")
     if hours == 72:
-        assert result.output == "1  [ ]    {}  aaa @default\x1b[0m\n".format(due_str)
+        assert result.output == f"1  [ ]    {due_str}  aaa @default\x1b[0m\n"
     else:
         assert (
             result.output
-            == "1  [ ]    \x1b[31m{}\x1b[0m  aaa @default\x1b[0m\n".format(due_str)
+            == f"1  [ ]    \x1b[31m{due_str}\x1b[0m  aaa @default\x1b[0m\n"
         )
 
 
@@ -517,7 +513,7 @@ def test_edit_inexistant(runner):
 
 def test_empty_list(tmpdir, runner, create):
     for item in tmpdir.listdir():
-        if isdir(str(item)):
+        if item.isdir():
             item.remove()
 
     result = runner.invoke(cli)
@@ -638,7 +634,7 @@ def test_todo_edit(runner, default_database, todo_factory):
 
 @pyicu_sensitive
 @freeze_time("2017, 3, 20")
-def test_list_startable(tmpdir, runner, todo_factory):
+def test_list_startable(tmpdir, runner, todo_factory, config):
     todo_factory(summary="started", start=datetime.datetime(2017, 3, 15))
     todo_factory(summary="nostart")
     todo_factory(summary="unstarted", start=datetime.datetime(2017, 3, 24))
@@ -665,8 +661,7 @@ def test_list_startable(tmpdir, runner, todo_factory):
     assert "nostart" in result.output
     assert "unstarted" in result.output
 
-    path = tmpdir.join("config")
-    path.write("startable = yes\n", "a")
+    config.write("startable = True\n", "a")
 
     result = runner.invoke(cli, ["list"], catch_exceptions=False)
 
@@ -679,11 +674,11 @@ def test_list_startable(tmpdir, runner, todo_factory):
 def test_bad_start_date(runner):
     result = runner.invoke(cli, ["list", "--start"])
     assert result.exception
-    assert result.output.strip() == "Error: --start option requires 2 arguments"
+    assert result.output.strip() == "Error: Option '--start' requires 2 arguments."
 
     result = runner.invoke(cli, ["list", "--start", "before"])
     assert result.exception
-    assert result.output.strip() == "Error: --start option requires 2 arguments"
+    assert result.output.strip() == "Error: Option '--start' requires 2 arguments."
 
     result = runner.invoke(cli, ["list", "--start", "before", "not_a_date"])
     assert result.exception
@@ -785,7 +780,7 @@ def test_status_validation():
         )
     )
     def run_test(statuses):
-        validated = cli.validate_status(val=",".join(statuses))
+        validated = cli.validate_status(val=",".join(statuses)).split(",")
 
         if "ANY" in statuses:
             assert len(validated) == 4
@@ -823,12 +818,11 @@ def test_status_filtering(runner, todo_factory):
     assert "two" in result.output
 
 
-def test_invoke_command(runner, tmpdir):
-    path = tmpdir.join("config")
-    path.write("default_command = flush\n", "a")
+def test_invoke_command(runner, tmpdir, config):
+    config.write('default_command = "flush"\n', "a")
 
     flush = mock.MagicMock()
-    with patch.dict(cli.commands, values=dict(flush=flush)):
+    with patch.dict(cli.commands, values={"flush": flush}):
         result = runner.invoke(cli, catch_exceptions=False)
 
     assert not result.exception
@@ -836,14 +830,13 @@ def test_invoke_command(runner, tmpdir):
     assert flush.call_count == 1
 
 
-def test_invoke_invalid_command(runner, tmpdir):
-    path = tmpdir.join("config")
-    path.write("default_command = DoTheRobot\n", "a")
+def test_invoke_invalid_command(runner, tmpdir, config):
+    config.write('default_command = "DoTheRobot"\n', "a")
 
     result = runner.invoke(cli, catch_exceptions=False)
 
     assert result.exception
-    assert "Error: Invalid setting for [main][default_command]" in result.output
+    assert "Error: Invalid setting for [default_command]" in result.output
 
 
 def test_show_priority(runner, todo_factory, todos):
@@ -914,10 +907,9 @@ def test_new_description_from_stdin(runner, todos):
     assert "hello" in todo.summary
 
 
-def test_default_priority(tmpdir, runner, create):
+def test_default_priority(tmpdir, runner, create, config):
     """Test setting the due date using the default_due config parameter"""
-    path = tmpdir.join("config")
-    path.write("default_priority = 3\n", "a")
+    config.write("default_priority = 3\n", "a")
 
     runner.invoke(cli, ["new", "-l", "default", "aaa"])
     db = Database([tmpdir.join("default")], tmpdir.join("/default_list"))
@@ -940,11 +932,10 @@ def test_no_default_priority(tmpdir, runner, create):
     assert "PRIORITY" not in todo_ics
 
 
-def test_invalid_default_priority(tmpdir, runner, create):
+def test_invalid_default_priority(config, runner, create):
     """Test setting the due date using the default_due config parameter"""
-    path = tmpdir.join("config")
-    path.write("default_priority = 13\n", "a")
+    config.write("default_priority = 13\n", "a")
 
     result = runner.invoke(cli, ["new", "-l", "default", "aaa"])
     assert result.exception
-    assert "Bad default_priority setting" in result.output
+    assert "Error: Invalid `default_priority` settings." in result.output
